@@ -1,4 +1,4 @@
 from .compare_screens import *
 from .detect_allgreen import *
 from .detect_green_screen_blur import *
-from .get_new_imagepath import *
+from .get_new_imagepath import get_new_image_path
